@@ -141,7 +141,7 @@ void CalendarClipboardPrivate::slotModifyFinished(int changeId, const Akonadi::I
 }
 
 void CalendarClipboardPrivate::slotDeleteFinished(int changeId,
-                                                  const QVector<Akonadi::Item::Id> &ids,
+                                                  const QList<Akonadi::Item::Id> &ids,
                                                   Akonadi::IncidenceChanger::ResultCode result,
                                                   const QString &errorMessage)
 {
@@ -249,3 +249,7 @@ bool CalendarClipboard::pasteAvailable() const
 {
     return KCalUtils::ICalDrag::canDecode(QApplication::clipboard()->mimeData());
 }
+
+#include "moc_calendarclipboard.cpp"
+
+#include "moc_calendarclipboard_p.cpp"
