@@ -16,7 +16,7 @@
 #include <KCalendarCore/Attendee>
 #include <KCalendarCore/Incidence>
 #include <KEmailAddress>
-#include <KIdentityManagement/Identity>
+#include <KIdentityManagementCore/Identity>
 #include <MessageComposer/ContactPreference>
 
 #include <Akonadi/MessageQueueJob>
@@ -48,7 +48,6 @@
 #include <KJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KProtocolManager>
 
 #include <QTemporaryDir>
 
@@ -91,7 +90,7 @@ static Kleo::chrono::days encryptChainCertNearExpiryWarningThresholdInDays()
     return Kleo::chrono::days{qMax(1, num)};
 }
 
-static bool cryptoWarningUnsigned(const KIdentityManagement::Identity &identity)
+static bool cryptoWarningUnsigned(const KIdentityManagementCore::Identity &identity)
 {
     if (identity.encryptionOverride()) {
         return identity.warnNotSign();
@@ -99,7 +98,7 @@ static bool cryptoWarningUnsigned(const KIdentityManagement::Identity &identity)
     return MessageComposer::MessageComposerSettings::self()->cryptoWarningUnsigned();
 }
 
-static bool cryptoWarningUnencrypted(const KIdentityManagement::Identity &identity)
+static bool cryptoWarningUnencrypted(const KIdentityManagementCore::Identity &identity)
 {
     if (identity.encryptionOverride()) {
         return identity.warnNotEncrypt();
@@ -139,7 +138,7 @@ void MailClient::populateKeyResolverContactsPreferences(Kleo::KeyResolver &keyRe
     }
 }
 
-static bool populateKeyResolverEncryptionKeys(Kleo::KeyResolver &keyResolver, const KIdentityManagement::Identity &identity)
+static bool populateKeyResolverEncryptionKeys(Kleo::KeyResolver &keyResolver, const KIdentityManagementCore::Identity &identity)
 {
     QStringList encryptToSelfKeys;
     if (!identity.pgpEncryptionKey().isEmpty()) {
@@ -156,7 +155,7 @@ static bool populateKeyResolverEncryptionKeys(Kleo::KeyResolver &keyResolver, co
     return true;
 }
 
-static bool populateKeyResolverSigningKeys(Kleo::KeyResolver &keyResolver, const KIdentityManagement::Identity &identity)
+static bool populateKeyResolverSigningKeys(Kleo::KeyResolver &keyResolver, const KIdentityManagementCore::Identity &identity)
 {
     QStringList signingKeys;
     if (!identity.pgpSigningKey().isEmpty()) {
@@ -175,15 +174,17 @@ static bool populateKeyResolverSigningKeys(Kleo::KeyResolver &keyResolver, const
 }
 
 std::vector<std::unique_ptr<MessageComposer::Composer>>
-MailClient::buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const MessageData &msg)
+MailClient::buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagementCore::Identity &identity, const MessageData &msg)
 {
     // TODO: Those should be set based on whether the user selects "Sign" or "Encrypt" options
     // in the incidence editor (similar to the "Sign" and "Encrypt" actions in KMail composer).
     // Right now we do NOT have those actions in the UI, so we keep the values to false so that
     // signing/encryption depends purely on current identity and attendee signing and encryption
     // preferences.
-    const bool doSignCompletely = false;
-    const bool doEncryptCompletely = false;
+    bool signSomething = msg.sign;
+    const bool doSignCompletely = msg.sign;
+    bool encryptSomething = msg.encrypt;
+    const bool doEncryptCompletely = msg.encrypt;
 
     std::unique_ptr<ITIPHandlerDialogDelegate> dialogDelegate(
         mFactory->createITIPHanderDialogDelegate(qSharedPointerCast<KCalendarCore::Incidence>(incidence), KCalendarCore::iTIPMethod::iTIPNoMethod));
@@ -211,8 +212,6 @@ MailClient::buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, c
         return {};
     }
 
-    bool signSomething = !identity.pgpSigningKey().isEmpty() && identity.pgpAutoSign();
-    bool encryptSomething = !identity.pgpEncryptionKey().isEmpty() && identity.pgpAutoEncrypt();
     bool result = true;
     bool canceled = false;
     bool signAttachments = false;
@@ -277,7 +276,7 @@ MailClient::buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, c
             auto composer = std::make_unique<MessageComposer::Composer>();
 
             if (encryptSomething || identity.autocryptEnabled()) {
-                QVector<QPair<QStringList, std::vector<GpgME::Key>>> data;
+                QList<QPair<QStringList, std::vector<GpgME::Key>>> data;
                 data.reserve(encData.size());
                 for (const auto &info : encData) {
                     data.push_back(qMakePair(info.recipients, info.keys));
@@ -316,7 +315,7 @@ MailClient::buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, c
 void MailClient::queueMessage(const MailTransport::Transport *transport,
                               const MessageComposer::Composer *composer,
                               const KCalendarCore::IncidenceBase::Ptr &incidence,
-                              const KIdentityManagement::Identity &identity,
+                              const KIdentityManagementCore::Identity &identity,
                               const MessageData &msg,
                               const KMime::Message::Ptr &message)
 {
@@ -364,10 +363,12 @@ MailClient::MailClient(ITIPHandlerComponentFactory *factory, QObject *parent)
 MailClient::~MailClient() = default;
 
 void MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidence,
-                               const KIdentityManagement::Identity &identity,
+                               const KIdentityManagementCore::Identity &identity,
+                               KCalendarCore::iTIPMethod method,
                                bool bccMe,
                                const QString &attachment,
-                               const QString &mailTransport)
+                               const QString &mailTransport,
+                               MailPrivacyFlags mailPrivacy)
 {
     Q_ASSERT(incidence);
     KCalendarCore::Attendee::List attendees = incidence->attendees();
@@ -381,6 +382,7 @@ void MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidenc
     msg.bccMe = bccMe;
     msg.attachment = attachment;
     msg.from = incidence->organizer().fullName();
+    msg.method = KCalendarCore::ScheduleMessage::methodName(method);
 
     const QString organizerEmail = incidence->organizer().email();
 
@@ -423,17 +425,21 @@ void MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidenc
     }
 
     msg.body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence);
+    msg.sign = (mailPrivacy & MailPrivacySign) == MailPrivacySign;
+    msg.encrypt = (mailPrivacy & MailPrivacyEncrypt) == MailPrivacyEncrypt;
 
     send(incidence, identity, msg, mailTransport);
 }
 
 void MailClient::mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidence,
-                               const KIdentityManagement::Identity &identity,
+                               const KIdentityManagementCore::Identity &identity,
                                const QString &from,
+                               KCalendarCore::iTIPMethod method,
                                bool bccMe,
                                const QString &attachment,
                                const QString &sub,
-                               const QString &mailTransport)
+                               const QString &mailTransport,
+                               MailPrivacyFlags mailPrivacy)
 {
     MessageData msg;
     msg.from = from;
@@ -441,6 +447,7 @@ void MailClient::mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidenc
     msg.bccMe = bccMe;
     msg.subject = sub;
     msg.attachment = attachment;
+    msg.method = KCalendarCore::ScheduleMessage::methodName(method);
 
     if (incidence->type() != KCalendarCore::Incidence::TypeFreeBusy) {
         KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
@@ -452,23 +459,28 @@ void MailClient::mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidenc
     }
 
     msg.body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence);
+    msg.sign = (mailPrivacy & MailPrivacySign) == MailPrivacySign;
+    msg.encrypt = (mailPrivacy & MailPrivacyEncrypt) == MailPrivacyEncrypt;
 
     send(incidence, identity, msg, mailTransport);
 }
 
 void MailClient::mailTo(const KCalendarCore::IncidenceBase::Ptr &incidence,
-                        const KIdentityManagement::Identity &identity,
+                        const KIdentityManagementCore::Identity &identity,
                         const QString &from,
+                        KCalendarCore::iTIPMethod method,
                         bool bccMe,
                         const QString &recipients,
                         const QString &attachment,
-                        const QString &mailTransport)
+                        const QString &mailTransport,
+                        MailPrivacyFlags mailPrivacy)
 {
     MessageData msg;
     msg.to = extractEmailAndNormalize(recipients);
     msg.from = from;
     msg.bccMe = bccMe;
     msg.attachment = attachment;
+    msg.method = KCalendarCore::ScheduleMessage::methodName(method);
 
     if (incidence->type() != KCalendarCore::Incidence::TypeFreeBusy) {
         KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
@@ -478,6 +490,8 @@ void MailClient::mailTo(const KCalendarCore::IncidenceBase::Ptr &incidence,
     }
 
     msg.body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence);
+    msg.sign = (mailPrivacy & MailPrivacySign) == MailPrivacySign;
+    msg.encrypt = (mailPrivacy & MailPrivacyEncrypt) == MailPrivacyEncrypt;
 
     send(incidence, identity, msg, mailTransport);
 }
@@ -518,10 +532,11 @@ void MailClient::populateComposer(MessageComposer::Composer *composer, const Mes
     itipPart->setOutlookConformInvitation(outlookConformInvitation);
     itipPart->setInvitationBody(msg.body);
     itipPart->setInvitation(msg.attachment);
+    itipPart->setMethod(msg.method);
 }
 
 bool MailClient::addKeysToContext(const QString &gnupgHome,
-                                  const QVector<QPair<QStringList, std::vector<GpgME::Key>>> &data,
+                                  const QList<QPair<QStringList, std::vector<GpgME::Key>>> &data,
                                   const std::map<QByteArray, QString> &autocryptMap)
 {
     bool needSpecialContext = false;
@@ -604,7 +619,7 @@ bool MailClient::addKeysToContext(const QString &gnupgHome,
 }
 
 void MailClient::send(const KCalendarCore::IncidenceBase::Ptr &incidence,
-                      const KIdentityManagement::Identity &identity,
+                      const KIdentityManagementCore::Identity &identity,
                       const MessageData &_msg,
                       const QString &mailTransport)
 {
@@ -659,7 +674,7 @@ void MailClient::handleQueueJobFinished(KJob *job)
 bool MailClient::determineWhetherToSign(bool doSignCompletely,
                                         Kleo::KeyResolver *keyResolver,
                                         ITIPHandlerDialogDelegate *dialogDelegate,
-                                        const KIdentityManagement::Identity &identity,
+                                        const KIdentityManagementCore::Identity &identity,
                                         bool signSomething,
                                         bool &signAttachments,
                                         bool &result,
@@ -774,7 +789,7 @@ bool MailClient::determineWhetherToSign(bool doSignCompletely,
 bool MailClient::determineWhetherToEncrypt(bool doEncryptCompletely,
                                            Kleo::KeyResolver *keyResolver,
                                            ITIPHandlerDialogDelegate *dialogDelegate,
-                                           const KIdentityManagement::Identity &identity,
+                                           const KIdentityManagementCore::Identity &identity,
                                            bool encryptSomething,
                                            bool signSomething,
                                            bool &encryptAttachments,
@@ -801,7 +816,7 @@ bool MailClient::determineWhetherToEncrypt(bool doEncryptCompletely,
     case Kleo::AskOpportunistic:
         opportunistic = true;
         // fall through...
-        Q_FALLTHROUGH();
+        [[fallthrough]];
     case Kleo::Ask: {
         // the user wants to be asked or has to be asked
         const QString msg = opportunistic ? i18n(
@@ -912,3 +927,5 @@ bool MailClient::showKeyApprovalDialog() const
 {
     return MessageComposer::MessageComposerSettings::self()->cryptoShowKeysForApproval();
 }
+
+#include "moc_mailclient_p.cpp"
