@@ -89,8 +89,7 @@ void PublishDialogPrivate::openAddressbook()
 {
     QPointer<Akonadi::AbstractEmailAddressSelectionDialog> dialog;
 
-    const KPluginMetaData editWidgetPlugin(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR))
-                                           + QStringLiteral("/akonadi/emailaddressselectionldapdialogplugin"));
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("pim6/akonadi/emailaddressselectionldapdialogplugin"));
 
     const auto result = KPluginFactory::instantiatePlugin<Akonadi::AbstractEmailAddressSelectionDialog>(editWidgetPlugin, q);
     if (result) {
@@ -147,3 +146,5 @@ void PublishDialogPrivate::updateInput()
     mUI.mNameLineEdit->setText(name);
     mUI.mEmailLineEdit->setText(mail);
 }
+
+#include "moc_publishdialog_p.cpp"
